Usage
==================

basic
----------------------------

.. automodule:: discogui.examples.basic

.. literalinclude:: ../discogui/examples/basic.py
      :lines: 6-
      
.. program-output:: python -m discogui.examples.basic
    :prompt:


button discovery on zenity
----------------------------

.. automodule:: discogui.examples.buttondiscovery

.. literalinclude:: ../discogui/examples/buttondiscovery.py
      :lines: 7-
      
.. program-screenshot:: python -m discogui.examples.buttondiscovery
    :prompt:
    :stdout:

button discovery on gnumeric
----------------------------

.. automodule:: discogui.examples.hovergnumeric

.. literalinclude:: ../discogui/examples/hovergnumeric.py
      :lines: 7-
      
.. program-screenshot:: python -m discogui.examples.hovergnumeric
    :prompt:
    :stdout:
    :timeout: 200

button test
---------------------

.. automodule:: discogui.examples.clickbutton

.. literalinclude:: ../discogui/examples/clickbutton.py
      :lines: 7-

.. program-output:: python -m discogui.examples.clickbutton
    :prompt:
